traceservices/tracefw/ulogger/unit_test/te-outfrwkchans/te-file/uloggerfileplugintest.cpp
branchRCL_3
changeset 23 26645d81f48d
parent 0 08ec8eefde2f
child 24 cc28652e0254
--- a/traceservices/tracefw/ulogger/unit_test/te-outfrwkchans/te-file/uloggerfileplugintest.cpp	Thu Aug 19 11:36:21 2010 +0300
+++ b/traceservices/tracefw/ulogger/unit_test/te-outfrwkchans/te-file/uloggerfileplugintest.cpp	Tue Aug 31 16:57:14 2010 +0300
@@ -36,7 +36,7 @@
 	delete fileWriter;
 	}
 /*
  * TestUnlockResources: Test that the CloseOutputPlugin method ???
  *
  * Expected Verdict: PASS/FAIL/PANIC
  *
@@ -45,7 +45,7 @@
  * Description: Retrieve and print some data from an external ini data file
  *
  */
-void CFile0Step::TestUnlockResources()
+void CFile0Step::TestUnlockResourcesL()
 	{
 	CFileWriter* fileWriter = CFileWriter::NewL();
 	INFO_PRINTF1(_L("Invoking CFileWriter::CloseOutputPlugin(). CloseOutputPlugin() is supposed to do nothing."));
@@ -55,7 +55,7 @@
 	}
 
 /*
  * TestSettings: Test that the Settings method ???
  *
  * Expected Verdict: PASS/FAIL/PANIC
  *
@@ -64,7 +64,7 @@
  * Description: Retrieve and print some data from an external ini data file
  *
  */
-void CFile0Step::TestSettings()
+void CFile0Step::TestSettingsL()
 	{
 	CFileWriter* fileWriter = CFileWriter::NewL();
 	INFO_PRINTF1(_L("Passing empty RPointerArray to CFileWriter::ConfigureOutputPlugin()"));
@@ -75,7 +75,7 @@
 	}
 
 /*
  * TestWrite: Test that the Write method ???
  *
  * Expected Verdict: PASS/FAIL/PANIC
  *
@@ -86,7 +86,7 @@
  *
  */
 // The implementation for this is not working correctly! Check this
-void CFile0Step::TestWrite()
+void CFile0Step::TestWriteL()
 	{
 	INFO_PRINTF1(_L("Checking that CFileWriter::Write(const TDesC8&) writes a String correctly to C:\\logs\\log.txt"));
 
@@ -136,9 +136,9 @@
 	  if (TestStepResult()==EPass)
 		{
 		TestNewL();
-		TestUnlockResources();
-		TestSettings();
-		TestWrite();
+		TestUnlockResourcesL();
+		TestSettingsL();
+		TestWriteL();
 		
 		if(iErrors == 0)
 			SetTestStepResult(EPass);
@@ -36,7 +36,7 @@
 	}
 /*
- * TestUnlockResources: Test that the CloseOutputPlugin method ???
+ * TestUnlockResourcesL: Test that the CloseOutputPlugin method ???
  *
  * Expected Verdict: PASS/FAIL/PANIC
@@ -55,7 +55,7 @@
 
 /*
- * TestSettings: Test that the Settings method ???
+ * TestSettingsL: Test that the Settings method ???
  *
  * Expected Verdict: PASS/FAIL/PANIC
@@ -75,7 +75,7 @@
 
 /*
- * TestWrite: Test that the Write method ???
+ * TestWriteL: Test that the Write method ???
  *
  * Expected Verdict: PASS/FAIL/PANIC